@@ -11,14 +11,6 @@
 class cmExecutionStatus
 {
 public:
-  cmExecutionStatus()
-    : ReturnInvoked(false)
-    , BreakInvoked(false)
-    , ContinueInvoked(false)
-    , NestedError(false)
-  {
-  }
-
   void Clear()
   {
     this->ReturnInvoked = false;
@@ -40,10 +32,10 @@ public:
   bool GetNestedError() const { return this->NestedError; }
 
 private:
-  bool ReturnInvoked;
-  bool BreakInvoked;
-  bool ContinueInvoked;
-  bool NestedError;
+  bool ReturnInvoked = false;
+  bool BreakInvoked = false;
+  bool ContinueInvoked = false;
+  bool NestedError = false;
 };
 
 #endif
